![PyPI - Python Version](https://img.shields.io/pypi/pyversions/my_lib_gens)
[![Documentation Status](https://readthedocs.org/projects/my-lib-gens/badge/?version=latest)](https://my-lib-gens.readthedocs.io/en/latest/?badge=latest)

# MyLib

Toy Python library project.
